@@ -21,8 +21,10 @@ pub enum ChatActionBar {
   #[doc(hidden)] _Default(()),
   /// The chat is a private or secret chat and the other user can be added to the contact list using the method addContact
   AddContact(ChatActionBarAddContact),
-  /// The chat is a recently created group chat, to which new members can be invited
+  /// The chat is a recently created group chat to which new members can be invited
   InviteMembers(ChatActionBarInviteMembers),
+  /// The chat is a private chat with an administrator of a chat to which the user sent join request
+  JoinRequest(ChatActionBarJoinRequest),
   /// The chat is a private or secret chat, which can be reported using the method reportChat, or the other user can be blocked using the method toggleMessageSenderIsBlocked, or the other user can be added to the contact list using the method addContact
   ReportAddBlock(ChatActionBarReportAddBlock),
   /// The chat can be reported as spam using the method reportChat with the reason chatReportReasonSpam
@@ -45,6 +47,7 @@ impl<'de> Deserialize<'de> for ChatActionBar {
       ChatActionBar,
       (chatActionBarAddContact, AddContact);
       (chatActionBarInviteMembers, InviteMembers);
+      (chatActionBarJoinRequest, JoinRequest);
       (chatActionBarReportAddBlock, ReportAddBlock);
       (chatActionBarReportSpam, ReportSpam);
       (chatActionBarReportUnrelatedLocation, ReportUnrelatedLocation);
@@ -59,6 +62,7 @@ impl RObject for ChatActionBar {
     match self {
       ChatActionBar::AddContact(t) => t.td_name(),
       ChatActionBar::InviteMembers(t) => t.td_name(),
+      ChatActionBar::JoinRequest(t) => t.td_name(),
       ChatActionBar::ReportAddBlock(t) => t.td_name(),
       ChatActionBar::ReportSpam(t) => t.td_name(),
       ChatActionBar::ReportUnrelatedLocation(t) => t.td_name(),
@@ -71,6 +75,7 @@ impl RObject for ChatActionBar {
     match self {
       ChatActionBar::AddContact(t) => t.extra(),
       ChatActionBar::InviteMembers(t) => t.extra(),
+      ChatActionBar::JoinRequest(t) => t.extra(),
       ChatActionBar::ReportAddBlock(t) => t.extra(),
       ChatActionBar::ReportSpam(t) => t.extra(),
       ChatActionBar::ReportUnrelatedLocation(t) => t.extra(),
@@ -88,6 +93,7 @@ impl ChatActionBar {
 
   pub fn is_add_contact(&self) -> bool { if let ChatActionBar::AddContact(_) = self { true } else { false } }
   pub fn is_invite_members(&self) -> bool { if let ChatActionBar::InviteMembers(_) = self { true } else { false } }
+  pub fn is_join_request(&self) -> bool { if let ChatActionBar::JoinRequest(_) = self { true } else { false } }
   pub fn is_report_add_block(&self) -> bool { if let ChatActionBar::ReportAddBlock(_) = self { true } else { false } }
   pub fn is_report_spam(&self) -> bool { if let ChatActionBar::ReportSpam(_) = self { true } else { false } }
   pub fn is_report_unrelated_location(&self) -> bool { if let ChatActionBar::ReportUnrelatedLocation(_) = self { true } else { false } }
@@ -95,6 +101,7 @@ impl ChatActionBar {
 
   pub fn on_add_contact<F: FnOnce(&ChatActionBarAddContact)>(&self, fnc: F) -> &Self { if let ChatActionBar::AddContact(t) = self { fnc(t) }; self }
   pub fn on_invite_members<F: FnOnce(&ChatActionBarInviteMembers)>(&self, fnc: F) -> &Self { if let ChatActionBar::InviteMembers(t) = self { fnc(t) }; self }
+  pub fn on_join_request<F: FnOnce(&ChatActionBarJoinRequest)>(&self, fnc: F) -> &Self { if let ChatActionBar::JoinRequest(t) = self { fnc(t) }; self }
   pub fn on_report_add_block<F: FnOnce(&ChatActionBarReportAddBlock)>(&self, fnc: F) -> &Self { if let ChatActionBar::ReportAddBlock(t) = self { fnc(t) }; self }
   pub fn on_report_spam<F: FnOnce(&ChatActionBarReportSpam)>(&self, fnc: F) -> &Self { if let ChatActionBar::ReportSpam(t) = self { fnc(t) }; self }
   pub fn on_report_unrelated_location<F: FnOnce(&ChatActionBarReportUnrelatedLocation)>(&self, fnc: F) -> &Self { if let ChatActionBar::ReportUnrelatedLocation(t) = self { fnc(t) }; self }
@@ -102,6 +109,7 @@ impl ChatActionBar {
 
   pub fn as_add_contact(&self) -> Option<&ChatActionBarAddContact> { if let ChatActionBar::AddContact(t) = self { return Some(t) } None }
   pub fn as_invite_members(&self) -> Option<&ChatActionBarInviteMembers> { if let ChatActionBar::InviteMembers(t) = self { return Some(t) } None }
+  pub fn as_join_request(&self) -> Option<&ChatActionBarJoinRequest> { if let ChatActionBar::JoinRequest(t) = self { return Some(t) } None }
   pub fn as_report_add_block(&self) -> Option<&ChatActionBarReportAddBlock> { if let ChatActionBar::ReportAddBlock(t) = self { return Some(t) } None }
   pub fn as_report_spam(&self) -> Option<&ChatActionBarReportSpam> { if let ChatActionBar::ReportSpam(t) = self { return Some(t) } None }
   pub fn as_report_unrelated_location(&self) -> Option<&ChatActionBarReportUnrelatedLocation> { if let ChatActionBar::ReportUnrelatedLocation(t) = self { return Some(t) } None }
@@ -113,6 +121,8 @@ impl ChatActionBar {
 
   pub fn invite_members<T: AsRef<ChatActionBarInviteMembers>>(t: T) -> Self { ChatActionBar::InviteMembers(t.as_ref().clone()) }
 
+  pub fn join_request<T: AsRef<ChatActionBarJoinRequest>>(t: T) -> Self { ChatActionBar::JoinRequest(t.as_ref().clone()) }
+
   pub fn report_add_block<T: AsRef<ChatActionBarReportAddBlock>>(t: T) -> Self { ChatActionBar::ReportAddBlock(t.as_ref().clone()) }
 
   pub fn report_spam<T: AsRef<ChatActionBarReportSpam>>(t: T) -> Self { ChatActionBar::ReportSpam(t.as_ref().clone()) }
@@ -191,7 +201,7 @@ impl AsRef<ChatActionBarAddContact> for RTDChatActionBarAddContactBuilder {
 
 
 
-/// The chat is a recently created group chat, to which new members can be invited
+/// The chat is a recently created group chat to which new members can be invited
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct ChatActionBarInviteMembers {
   #[doc(hidden)]
@@ -249,6 +259,94 @@ impl AsRef<ChatActionBarInviteMembers> for RTDChatActionBarInviteMembersBuilder
 
 
 
+/// The chat is a private chat with an administrator of a chat to which the user sent join request
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct ChatActionBarJoinRequest {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  /// Title of the chat to which the join request was sent
+  title: String,
+  /// True, if the join request was sent to a channel chat
+  is_channel: bool,
+  /// Point in time (Unix timestamp) when the join request was sent
+  request_date: i64,
+  
+}
+
+impl RObject for ChatActionBarJoinRequest {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "chatActionBarJoinRequest" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDChatActionBar for ChatActionBarJoinRequest {}
+
+
+
+impl ChatActionBarJoinRequest {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDChatActionBarJoinRequestBuilder {
+    let mut inner = ChatActionBarJoinRequest::default();
+    inner.td_name = "chatActionBarJoinRequest".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDChatActionBarJoinRequestBuilder { inner }
+  }
+
+  pub fn title(&self) -> &String { &self.title }
+
+  pub fn is_channel(&self) -> bool { self.is_channel }
+
+  pub fn request_date(&self) -> i64 { self.request_date }
+
+}
+
+#[doc(hidden)]
+pub struct RTDChatActionBarJoinRequestBuilder {
+  inner: ChatActionBarJoinRequest
+}
+
+impl RTDChatActionBarJoinRequestBuilder {
+  pub fn build(&self) -> ChatActionBarJoinRequest { self.inner.clone() }
+
+   
+  pub fn title<T: AsRef<str>>(&mut self, title: T) -> &mut Self {
+    self.inner.title = title.as_ref().to_string();
+    self
+  }
+
+   
+  pub fn is_channel(&mut self, is_channel: bool) -> &mut Self {
+    self.inner.is_channel = is_channel;
+    self
+  }
+
+   
+  pub fn request_date(&mut self, request_date: i64) -> &mut Self {
+    self.inner.request_date = request_date;
+    self
+  }
+
+}
+
+impl AsRef<ChatActionBarJoinRequest> for ChatActionBarJoinRequest {
+  fn as_ref(&self) -> &ChatActionBarJoinRequest { self }
+}
+
+impl AsRef<ChatActionBarJoinRequest> for RTDChatActionBarJoinRequestBuilder {
+  fn as_ref(&self) -> &ChatActionBarJoinRequest { &self.inner }
+}
+
+
+
+
+
+
+
 /// The chat is a private or secret chat, which can be reported using the method reportChat, or the other user can be blocked using the method toggleMessageSenderIsBlocked, or the other user can be added to the contact list using the method addContact
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct ChatActionBarReportAddBlock {
