@@ -19,7 +19,7 @@ pub trait TDSuggestedAction: Debug + RObject {}
 #[serde(untagged)]
 pub enum SuggestedAction {
   #[doc(hidden)] _Default(()),
-  /// Suggests the user to check whether 2-step verification password is still remembered
+  /// Suggests the user to check whether they still remember their 2-step verification password
   CheckPassword(SuggestedActionCheckPassword),
   /// Suggests the user to check whether authorization phone number is correct and change the phone number if it is inaccessible
   CheckPhoneNumber(SuggestedActionCheckPhoneNumber),
@@ -27,10 +27,10 @@ pub enum SuggestedAction {
   ConvertToBroadcastGroup(SuggestedActionConvertToBroadcastGroup),
   /// Suggests the user to enable "archive_and_mute_new_chats_from_unknown_users" option
   EnableArchiveAndMuteNewChats(SuggestedActionEnableArchiveAndMuteNewChats),
-  /// Suggests the user to see a hint about meaning of one and two ticks on sent messages
-  SeeTicksHint(SuggestedActionSeeTicksHint),
   /// Suggests the user to set a 2-step verification password to be able to log in again
   SetPassword(SuggestedActionSetPassword),
+  /// Suggests the user to view a hint about the meaning of one and two check marks on sent messages
+  ViewChecksHint(SuggestedActionViewChecksHint),
 
 }
 
@@ -47,8 +47,8 @@ impl<'de> Deserialize<'de> for SuggestedAction {
       (suggestedActionCheckPhoneNumber, CheckPhoneNumber);
       (suggestedActionConvertToBroadcastGroup, ConvertToBroadcastGroup);
       (suggestedActionEnableArchiveAndMuteNewChats, EnableArchiveAndMuteNewChats);
-      (suggestedActionSeeTicksHint, SeeTicksHint);
       (suggestedActionSetPassword, SetPassword);
+      (suggestedActionViewChecksHint, ViewChecksHint);
 
     )(deserializer)
   }
@@ -61,8 +61,8 @@ impl RObject for SuggestedAction {
       SuggestedAction::CheckPhoneNumber(t) => t.td_name(),
       SuggestedAction::ConvertToBroadcastGroup(t) => t.td_name(),
       SuggestedAction::EnableArchiveAndMuteNewChats(t) => t.td_name(),
-      SuggestedAction::SeeTicksHint(t) => t.td_name(),
       SuggestedAction::SetPassword(t) => t.td_name(),
+      SuggestedAction::ViewChecksHint(t) => t.td_name(),
 
       _ => "-1",
     }
@@ -73,8 +73,8 @@ impl RObject for SuggestedAction {
       SuggestedAction::CheckPhoneNumber(t) => t.extra(),
       SuggestedAction::ConvertToBroadcastGroup(t) => t.extra(),
       SuggestedAction::EnableArchiveAndMuteNewChats(t) => t.extra(),
-      SuggestedAction::SeeTicksHint(t) => t.extra(),
       SuggestedAction::SetPassword(t) => t.extra(),
+      SuggestedAction::ViewChecksHint(t) => t.extra(),
 
       _ => None,
     }
@@ -90,22 +90,22 @@ impl SuggestedAction {
   pub fn is_check_phone_number(&self) -> bool { if let SuggestedAction::CheckPhoneNumber(_) = self { true } else { false } }
   pub fn is_convert_to_broadcast_group(&self) -> bool { if let SuggestedAction::ConvertToBroadcastGroup(_) = self { true } else { false } }
   pub fn is_enable_archive_and_mute_new_chats(&self) -> bool { if let SuggestedAction::EnableArchiveAndMuteNewChats(_) = self { true } else { false } }
-  pub fn is_see_ticks_hint(&self) -> bool { if let SuggestedAction::SeeTicksHint(_) = self { true } else { false } }
   pub fn is_set_password(&self) -> bool { if let SuggestedAction::SetPassword(_) = self { true } else { false } }
+  pub fn is_view_checks_hint(&self) -> bool { if let SuggestedAction::ViewChecksHint(_) = self { true } else { false } }
 
   pub fn on_check_password<F: FnOnce(&SuggestedActionCheckPassword)>(&self, fnc: F) -> &Self { if let SuggestedAction::CheckPassword(t) = self { fnc(t) }; self }
   pub fn on_check_phone_number<F: FnOnce(&SuggestedActionCheckPhoneNumber)>(&self, fnc: F) -> &Self { if let SuggestedAction::CheckPhoneNumber(t) = self { fnc(t) }; self }
   pub fn on_convert_to_broadcast_group<F: FnOnce(&SuggestedActionConvertToBroadcastGroup)>(&self, fnc: F) -> &Self { if let SuggestedAction::ConvertToBroadcastGroup(t) = self { fnc(t) }; self }
   pub fn on_enable_archive_and_mute_new_chats<F: FnOnce(&SuggestedActionEnableArchiveAndMuteNewChats)>(&self, fnc: F) -> &Self { if let SuggestedAction::EnableArchiveAndMuteNewChats(t) = self { fnc(t) }; self }
-  pub fn on_see_ticks_hint<F: FnOnce(&SuggestedActionSeeTicksHint)>(&self, fnc: F) -> &Self { if let SuggestedAction::SeeTicksHint(t) = self { fnc(t) }; self }
   pub fn on_set_password<F: FnOnce(&SuggestedActionSetPassword)>(&self, fnc: F) -> &Self { if let SuggestedAction::SetPassword(t) = self { fnc(t) }; self }
+  pub fn on_view_checks_hint<F: FnOnce(&SuggestedActionViewChecksHint)>(&self, fnc: F) -> &Self { if let SuggestedAction::ViewChecksHint(t) = self { fnc(t) }; self }
 
   pub fn as_check_password(&self) -> Option<&SuggestedActionCheckPassword> { if let SuggestedAction::CheckPassword(t) = self { return Some(t) } None }
   pub fn as_check_phone_number(&self) -> Option<&SuggestedActionCheckPhoneNumber> { if let SuggestedAction::CheckPhoneNumber(t) = self { return Some(t) } None }
   pub fn as_convert_to_broadcast_group(&self) -> Option<&SuggestedActionConvertToBroadcastGroup> { if let SuggestedAction::ConvertToBroadcastGroup(t) = self { return Some(t) } None }
   pub fn as_enable_archive_and_mute_new_chats(&self) -> Option<&SuggestedActionEnableArchiveAndMuteNewChats> { if let SuggestedAction::EnableArchiveAndMuteNewChats(t) = self { return Some(t) } None }
-  pub fn as_see_ticks_hint(&self) -> Option<&SuggestedActionSeeTicksHint> { if let SuggestedAction::SeeTicksHint(t) = self { return Some(t) } None }
   pub fn as_set_password(&self) -> Option<&SuggestedActionSetPassword> { if let SuggestedAction::SetPassword(t) = self { return Some(t) } None }
+  pub fn as_view_checks_hint(&self) -> Option<&SuggestedActionViewChecksHint> { if let SuggestedAction::ViewChecksHint(t) = self { return Some(t) } None }
 
 
 
@@ -117,10 +117,10 @@ impl SuggestedAction {
 
   pub fn enable_archive_and_mute_new_chats<T: AsRef<SuggestedActionEnableArchiveAndMuteNewChats>>(t: T) -> Self { SuggestedAction::EnableArchiveAndMuteNewChats(t.as_ref().clone()) }
 
-  pub fn see_ticks_hint<T: AsRef<SuggestedActionSeeTicksHint>>(t: T) -> Self { SuggestedAction::SeeTicksHint(t.as_ref().clone()) }
-
   pub fn set_password<T: AsRef<SuggestedActionSetPassword>>(t: T) -> Self { SuggestedAction::SetPassword(t.as_ref().clone()) }
 
+  pub fn view_checks_hint<T: AsRef<SuggestedActionViewChecksHint>>(t: T) -> Self { SuggestedAction::ViewChecksHint(t.as_ref().clone()) }
+
 }
 
 impl AsRef<SuggestedAction> for SuggestedAction {
@@ -133,7 +133,7 @@ impl AsRef<SuggestedAction> for SuggestedAction {
 
 
 
-/// Suggests the user to check whether 2-step verification password is still remembered
+/// Suggests the user to check whether they still remember their 2-step verification password
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct SuggestedActionCheckPassword {
   #[doc(hidden)]
@@ -375,64 +375,6 @@ impl AsRef<SuggestedActionEnableArchiveAndMuteNewChats> for RTDSuggestedActionEn
 
 
 
-/// Suggests the user to see a hint about meaning of one and two ticks on sent messages
-#[derive(Debug, Clone, Default, Serialize, Deserialize)]
-pub struct SuggestedActionSeeTicksHint {
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@type", deserialize = "@type"))]
-  td_name: String,
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
-  extra: Option<String>,
-  
-}
-
-impl RObject for SuggestedActionSeeTicksHint {
-  #[doc(hidden)] fn td_name(&self) -> &'static str { "suggestedActionSeeTicksHint" }
-  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
-  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
-}
-
-
-impl TDSuggestedAction for SuggestedActionSeeTicksHint {}
-
-
-
-impl SuggestedActionSeeTicksHint {
-  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
-  pub fn builder() -> RTDSuggestedActionSeeTicksHintBuilder {
-    let mut inner = SuggestedActionSeeTicksHint::default();
-    inner.td_name = "suggestedActionSeeTicksHint".to_string();
-    inner.extra = Some(Uuid::new_v4().to_string());
-    RTDSuggestedActionSeeTicksHintBuilder { inner }
-  }
-
-}
-
-#[doc(hidden)]
-pub struct RTDSuggestedActionSeeTicksHintBuilder {
-  inner: SuggestedActionSeeTicksHint
-}
-
-impl RTDSuggestedActionSeeTicksHintBuilder {
-  pub fn build(&self) -> SuggestedActionSeeTicksHint { self.inner.clone() }
-
-}
-
-impl AsRef<SuggestedActionSeeTicksHint> for SuggestedActionSeeTicksHint {
-  fn as_ref(&self) -> &SuggestedActionSeeTicksHint { self }
-}
-
-impl AsRef<SuggestedActionSeeTicksHint> for RTDSuggestedActionSeeTicksHintBuilder {
-  fn as_ref(&self) -> &SuggestedActionSeeTicksHint { &self.inner }
-}
-
-
-
-
-
-
-
 /// Suggests the user to set a 2-step verification password to be able to log in again
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct SuggestedActionSetPassword {
@@ -497,3 +439,61 @@ impl AsRef<SuggestedActionSetPassword> for RTDSuggestedActionSetPasswordBuilder
 
 
 
+
+
+
+
+/// Suggests the user to view a hint about the meaning of one and two check marks on sent messages
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct SuggestedActionViewChecksHint {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  
+}
+
+impl RObject for SuggestedActionViewChecksHint {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "suggestedActionViewChecksHint" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDSuggestedAction for SuggestedActionViewChecksHint {}
+
+
+
+impl SuggestedActionViewChecksHint {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDSuggestedActionViewChecksHintBuilder {
+    let mut inner = SuggestedActionViewChecksHint::default();
+    inner.td_name = "suggestedActionViewChecksHint".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDSuggestedActionViewChecksHintBuilder { inner }
+  }
+
+}
+
+#[doc(hidden)]
+pub struct RTDSuggestedActionViewChecksHintBuilder {
+  inner: SuggestedActionViewChecksHint
+}
+
+impl RTDSuggestedActionViewChecksHintBuilder {
+  pub fn build(&self) -> SuggestedActionViewChecksHint { self.inner.clone() }
+
+}
+
+impl AsRef<SuggestedActionViewChecksHint> for SuggestedActionViewChecksHint {
+  fn as_ref(&self) -> &SuggestedActionViewChecksHint { self }
+}
+
+impl AsRef<SuggestedActionViewChecksHint> for RTDSuggestedActionViewChecksHintBuilder {
+  fn as_ref(&self) -> &SuggestedActionViewChecksHint { &self.inner }
+}
+
+
+
